library(FSA)
library(propagate)
library(minpack.lm)

#Load data
data<-read.csv("Femur Histology Data.csv", header=TRUE)
data<-subset(data, data$LAG.no.!='Periosteum')
data<-subset(data, data$LAG.no.!='1')
data
sue<-subset(data, data$Nickname=='Sue')
petey<-subset(data, data$Nickname=='Petey')
jane<-subset(data, data$Nickname=='Jane')
janeC<-subset(data, data$Nickname=='Jane (corrected)')

#Plot
plot(sue$X.LAG.no...including.periosteum, sue$Mass..kg...Campione.et.al...2014...eqn..7.., xlab="LAG number at death (age independent)", ylab="Body mass estimate (kg)",cex.lab=1.25, xlim=c(-10,40), ylim=c(0,10000), col='white')

#add Longrich et al. (in review) asymptotes based on multi-individual regressions 
# where each specimen was assigned a single age and mass, 
# without the hacthling size correction described and applied therein
abline(h=7944.1463) #Tyrannosaurus
abline(h=3121.6738) #Gorgosaurus
abline(h=1569.9217) #Albertosaurus


#fit logistic growth model to whole Sue data
x<-as.numeric(sue$X.LAG.no...including.periosteum)
y<-as.numeric(sue$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.sue <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=8500, k=-0.3, p=1.25), data=as.list(sue))
logistic.sue
points(x=seq(from=-20, to=50, by=0.1), y=(8194.1806)/(1+exp((1.4664)+(-0.3521)*(seq(from=-20, to=50, by=0.1)))), type="l", col="RED", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole Sue data
x<-as.numeric(sue$X.LAG.no...including.periosteum)
y<-as.numeric(sue$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.sue<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=8400), data=as.list(sue))
gompertz.sue
points(x=seq(from=-20, to=50, by=0.1), y=(8286.8463)*2.71828^(-2.71828^(-(0.2671)*(seq(from=-20, to=50, by=0.1)-(2.7144)))), type="l", col="RED", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit logarithmic growth model to whole Sue data
x<-as.numeric(sue$X.LAG.no...including.periosteum)
y<-as.numeric(sue$Mass..kg...Campione.et.al...2014...eqn..7..)
model.sue <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.sue,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='RED', lty=3)

#fit VB growth model to whole Sue data
x<-as.numeric(sue$X.LAG.no...including.periosteum)
y<-as.numeric(sue$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define Von Bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(sue),start=list(Linf=10000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(8463.1409)*(1-exp(-(0.1867)*((seq(from=-20, to=50, by=0.1))-(0.2623)))), type="l", col="RED", lwd=2, lty=4) #Insert the parameters found in the model manually

##########

#fit logistic growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.janeC <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=900, k=-0.3, p=1.25), data=as.list(janeC))
logistic.janeC
points(x=seq(from=-20, to=50, by=0.1), y=(1230.4735)/(1+exp((0.9460)+(-0.3981)*(seq(from=-20, to=50, by=0.1)))), type="l", col="BLUE", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.janeC<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=900), data=as.list(janeC))
gompertz.janeC
points(x=seq(from=-20, to=50, by=0.1), y=(1372.2137)*2.71828^(-2.71828^(-(0.2529)*(seq(from=-20, to=50, by=0.1)-(1.4968)))), type="l", col="BLUE", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit Logarithmic growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
model.janeC <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.janeC,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='BLUE', lty=3)

#fit VB growth model to whole JaneC data
x<-as.numeric(janeC$X.LAG.no...including.periosteum)
y<-as.numeric(janeC$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define von bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(janeC),start=list(Linf=1000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(1782.5247)*(1-exp(-(0.1089)*((seq(from=-20, to=50, by=0.1))-(-1.5295)))), type="l", col="BLUE", lwd=2, lty=4) #Insert the parameters found in the model manually



##########

#fit logistic growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
logistic.petey <- nlsLM(y~L/(1+exp(p+k*x)), start=list(L=900, k=-0.3, p=1.25), data=as.list(petey))
logistic.petey
points(x=seq(from=-20, to=50, by=0.1), y=(709.2381)/(1+exp((2.0833)+(-0.8094)*(seq(from=-20, to=50, by=0.1)))), type="l", col="GREEN", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
gompertz.petey<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), start=list(i=3,k=0.25,l=900), data=as.list(petey))
gompertz.petey
points(x=seq(from=-20, to=50, by=0.1), y=(731.5850)*2.71828^(-2.71828^(-(0.5903)*(seq(from=-20, to=50, by=0.1)-(1.9956)))), type="l", col="GREEN", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit Logarithmic growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
model.petey <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.petey,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='GREEN', lty=3)

#fit VB growth model to whole Petey data
x<-as.numeric(petey$X.LAG.no...including.periosteum)
y<-as.numeric(petey$Mass..kg...Campione.et.al...2014...eqn..7..)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define von bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(petey),start=list(Linf=1000, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), y=(775.4492)*(1-exp(-(0.3789)*((seq(from=-20, to=50, by=0.1))-(0.8852)))), type="l", col="GREEN", lwd=2, lty=4) #Insert the parameters found in the model manually



##############################
points(sue$X.LAG.no...including.periosteum, sue$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=16)
points(janeC$X.LAG.no...including.periosteum, janeC$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=15)
points(petey$X.LAG.no...including.periosteum, petey$Mass..kg...Campione.et.al...2014...eqn..7.., cex.lab=1.5, pch=17)
